# https://nixos.wiki/wiki/Java

{ fetchzip,
  makeWrapper,
  stdenv,
  writeShellScript,
  jre,

  version ? "4.5.8",
  hash ? "sha256-HZHNyw+LrxAN4OLueAhyxRG2onPWNMm5MwJDLLzsE2M="
}:

stdenv.mkDerivation (finalAttrs:
  let
    startServer = writeShellScript "startCoreNLPServer.sh" ''
      set -x
      PORT=9000
  
      while getopts ':p:h' opt; do
        case $opt in
          (p) PORT=$OPTARG;;
          (h) echo "$(basename $0) [-p 9000]"
              exit 0
              ;;
        esac
      done
  
      shift "$((OPTIND - 1))"

      ${jre}/bin/java -mx4g -cp "$CORENLP_PATH/*" edu.stanford.nlp.pipeline.StanfordCoreNLPServer -port $PORT -timeout 15000 "$@"
    '';
  in

  {
    name = "corenlp";
    inherit version;
    src = fetchzip {
      inherit hash;
      url = "http://nlp.stanford.edu/software/stanford-corenlp-${finalAttrs.version}.zip";
    };
    buildInputs = [
      jre
    ];
    nativeBuildInputs = [
      makeWrapper
    ];
    phases = [ "unpackPhase" "installPhase" ];
    installPhase = ''
      runHook preInstall
      mkdir -p $out/bin
      mkdir -p $out/share/corenlp
      cp -r . $out/share/corenlp
      makeWrapper ${startServer} $out/bin/startCoreNLPServer.sh \
        --set CORENLP_PATH "$out/share/corenlp"
      runHook postInstall
    '';
  }
)
